@@ -13,28 +13,39 @@
 #     You should have received a copy of the GNU General Public License
 #     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from . import (BDstat, base, base_zeo, bdparser, coating, conffile_zeo, job,
-               jobselector, loader, lowercase_btree, run_zeo, runselector)
-from .base import *
-from .base_zeo import *
-from .bdparser import *
-from .BDstat import *
-from .conffile_zeo import *
-from .job import *
-from .jobselector import *
-from .lowercase_btree import *
-from .run_zeo import *
-from .runselector import *
+import lazy_loader as lazy
+import warnings
 
-__all__ = ["job", "base"]
-__all__.extend(bdparser.__all__)
-__all__.extend(base.__all__)
-__all__.extend(base_zeo.__all__)
-__all__.extend(runselector.__all__)
-__all__.extend(jobselector.__all__)
-__all__.extend(conffile_zeo.__all__)
-__all__.extend(BDstat.__all__)
+warnings.filterwarnings(
+    "ignore", message=".*subpackages can technically be lazily loaded.*"
+)
 
+__getattr__, __dir__, __all__ = lazy.attach(
+    __name__,
+    [
+        "base",
+        "base_zeo",
+        "bdparser",
+        "jobselector",
+        "run_zeo",
+        "runselector",
+        "run_zeo",
+        # "BDstat",
+        # "coating",
+        # "conffile_zeo",
+        # "job",
+        # "loader",
+        # "lowercase_btree",
+    ],
+    submod_attrs={
+        "bdparser": ["BDParser", "RunParser"],
+        "base": ["Base"],
+        "base_zeo": ["BaseZEO"],
+        "runselector": ["RunSelector"],
+        "jobselector": ["JobSelector"],
+        "run_zeo": ["RunZEO", "getRunFromScript"],
+    },
+)
 
 ################################################################
 
