@@ -22,6 +22,7 @@ import subprocess
 import sys
 
 import psutil
+
 ################################################################
 import yaml
 import ZEO
@@ -29,8 +30,16 @@ import ZODB
 from BTrees.OOBTree import BTree, OOSet
 
 ################################################################
-from . import (base, bdlogging, bdparser, conffile_zeo, job, lowercase_btree,
-               run_zeo, zeoobject)
+from . import (
+    base,
+    bdlogging,
+    bdparser,
+    conffile_zeo,
+    job,
+    lowercase_btree,
+    run_zeo,
+    zeoobject,
+)
 from .constraints_zeo import ZEOconstraints
 
 ################################################################
@@ -920,7 +929,12 @@ class BaseZEO(base.AbstractBase):
         os.chdir(mydir)
 
         for r, j in run_list:
-            logger.warning(f"Dealing with job {j.id}, run {r.id}")
+            if r.state != "CREATED":
+                continue
+            if params["truerun"] is True:
+                r["state"] = "TOBELAUNCHED"
+                self.commit()
+            logger.info(f"Dealing with job {j.id}, run {r.id}")
             r["run_path"] = os.path.join(mydir, "run-" + str(r.id))
             from . import __version__ as BD_version
 
@@ -947,14 +961,14 @@ class BaseZEO(base.AbstractBase):
 
             conffiles = r.getConfigFiles()
             for conf in conffiles:
-                logger.warning("create file " + conf["filename"])
+                logger.info("create file " + conf["filename"])
                 f = open(conf["filename"], "w")
                 f.write(conf["file"])
                 f.close()
 
-            logger.warning("launch in '" + mydir + "/" + "run-" + str(r.id) + "/'")
+            logger.info("launch in '" + mydir + "/" + "run-" + str(r.id) + "/'")
             mymod = params["generator"]
-            logger.warning(mymod)
+            logger.info(mymod)
             mymod.launch(r, params)
 
             os.chdir("../")
