@@ -35,20 +35,28 @@ def validate(question, params):
 
     return validated
 
+
 ################################################################
 
 
 def main(argv=None):
-    parser = BD.BDParser(description='cleanRuns')
+    parser = BD.BDParser(description="cleanRuns")
     group = parser.register_group("cleanRuns")
     group.add_argument(
-        "--run_id", type=int,
-        help="In case cleaning a single run: ID of this specific run")
+        "--run_id",
+        type=int,
+        help="In case cleaning a single run: ID of this specific run",
+    )
     group.add_argument("--clean_orphans", type=str)
-    group.add_argument("--machine_name", type=str, default=socket.gethostname(),
-                       help="Machine name for desired runs")
-    group.add_argument("--delete", action='store_true',
-                       help="Entirely remove runs from database")
+    group.add_argument(
+        "--machine_name",
+        type=str,
+        default=socket.gethostname(),
+        help="Machine name for desired runs",
+    )
+    group.add_argument(
+        "--delete", action="store_true", help="Entirely remove runs from database"
+    )
 
     params = parser.parseBDParameters(argv)
     if "constraints" not in params:
@@ -60,11 +68,10 @@ def main(argv=None):
     if "machine_name" in params:
         machine_already_constrained = False
         for e in params["constraints"]:
-            if 'machine_name' in e:
+            if "machine_name" in e:
                 machine_already_constrained = True
         if not machine_already_constrained:
-            params["constraints"].append(
-                "machine_name = " + params["machine_name"])
+            params["constraints"].append("machine_name = " + params["machine_name"])
 
     base = BD.Base(**params)
     runSelector = BD.RunSelector(base)
@@ -83,19 +90,18 @@ def main(argv=None):
         for filename in os.listdir(resdir):
             fullname = os.path.join(resdir, filename)
             # print(fullname)
-            if (os.path.isdir(fullname)):
+            if os.path.isdir(fullname):
                 match = re.match("run-([0-9]+)", filename)
-                if (match):
+                if match:
                     # print(filename)
                     id = int(match.group(1))
-                    if (id not in run_ids):
+                    if id not in run_ids:
                         to_delete[id] = fullname
-        if (len(to_delete.keys()) == 0):
+        if len(to_delete.keys()) == 0:
             print("No orphans found")
             sys.exit(0)
 
-        validated = validate("Delete output from runs " +
-                             str(to_delete.keys()), params)
+        validated = validate("Delete output from runs " + str(to_delete.keys()), params)
         if validated:
             for id, fullname in to_delete.items():
                 # print("Delete output from run " + str(id))
@@ -124,15 +130,18 @@ def main(argv=None):
             run_path = None
         if run_path:
             if os.path.exists(run_path):
-                if (validated):
+                if validated:
                     # print("Deleting directory: " + run_path)
                     shutil.rmtree(run_path)
                 else:
                     # print("Simulate deletion of directory: " + run_path)
                     pass
             else:
-                print("output directory: '" + run_path +
-                      "' not found: are we on the right machine ?")
+                print(
+                    "output directory: '"
+                    + run_path
+                    + "' not found: are we on the right machine ?"
+                )
 
         if delete_flag:
             if validated:
