@@ -18,6 +18,7 @@
 import BlackDynamite as BD
 from BlackDynamite.graphhelper import GraphParser
 from BlackDynamite.graphhelper import GraphHelper
+
 ################################################################
 
 
@@ -25,11 +26,10 @@ def main(argv=None):
 
     parser = GraphParser()
     params = parser.parseBDParameters(argv)
-    print(params)
     base = BD.Base(**params)
     gH = GraphHelper(base, **params)
     gH.makeGraphs(**params)
-    if 'fileout' not in params:
+    if "fileout" not in params:
         gH.show()
 
 
